/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2008, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors. 
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.test.security.ejb2;

import java.rmi.RemoteException;
import java.security.Principal;

import javax.ejb.EJBObject;

/**
 * <p>
 * This is the remote interface of the session bean used in the EJB2 SAML security test.
 * </p>
 * 
 * @author <a href="mailto:sguilhen@redhat.com">Stefan Guilhen</a>
 */
public interface SimpleEJB2Session extends EJBObject
{
   /**
    * <p>
    * This is a method available for regular users and administrators. The deployment descriptor must enforce that
    * only users in RegularUser or Administrator roles are granted access to this method.
    * </p>
    * 
    * @return the caller's {@code Principal}.
    */
   public Principal invokeRegularMethod() throws RemoteException;

   /**
    * <p>
    * This is a method available for administrators only. The deployment descriptor must enforce that only users in the
    * Administrator role are granted access to this method.
    * </p>
    * 
    * @return the caller's {@code Principal}.
    */
   public Principal invokeAdministrativeMethod() throws RemoteException;

   /**
    * <p>
    * This is a method available for all authenticated users, regardless or role. The deployment descriptor must
    * contain an {@code unchecked} element for this method.
    * </p>
    * 
    * @return the caller's {@code Principal}.
    */
   public Principal invokeUnprotectedMethod() throws RemoteException;

   /**
    * <p>
    * This is a method that is unavailable for all roles. The deployment descriptor must add this method to the
    * {@code exclude-list} element.
    * </p>
    * 
    * @return the caller's {@code Principal}.
    */
   public Principal invokeUnavailableMethod() throws RemoteException;

}
